@@ -15,7 +15,6 @@ use Set::Intersection;
 use List::MoreUtils qw(uniq);
 use List::AllUtils qw(sum);
 use Data::Dump qw(dump);
-use Storable qw(dclone);
 use IO::Tee;
 use feature 'say';
 no strict;
@@ -32,7 +31,7 @@ no warnings;
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart );
 
-$VERSION = '0.003';
+$VERSION = '0.005';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries.';
 
 #######################################################################
@@ -42,7 +41,7 @@ $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, m
 
 
 my $maxloops= 1000;
-my $sourcefile = "/home/luca/int/starcloud_small.csv";
+my $sourcefile = "/home/luca/int/starcloud_small3.csv";
 my $newfile = $sourcefile . "_new.csv";
 my $report = $newfile . "_report.txt";
 my @mode = ( "wei" ); # #"wei" is weighted gradient linear interpolation of the nearest neighbours.
@@ -168,27 +167,50 @@ sub adjustmode
   return( @mode );
 }
 
+
+
 sub preparearr
 {
   my @lines = @_;
   foreach my $line ( @lines )
   {
+    my ( @row, @pars );
+    my ( $header );
     chomp( $line );
-    my @row = split( /,/ , $line );
-    my @pars = split( /_/ , $row[0] );
-    if ( $row[1] eq undef )
+    if ( $line =~ /_/ )
     {
-      push ( @arr, [ $row[0], [ @pars ] ] );
+      @row = split( /,/ , $line );
+      @pars = split( /_/ , $row[0] );
+      $header = $row[0];
     }
     else
     {
-      push ( @arr, [ $row[0], [ @pars ], $row[1], 1 ] );
+      @row = split( /,/ , $line );
+      $rightnum = scalar( @row - 1 );
+      my $count = 1;
+      while ( $count < $rightnum )
+      {
+        my $bit = join( "-", ( $count, $row[$count-1] ) );
+        push( @pars, $bit );
+        $count++;
+      }
+      $header = join( "_", @pars )
+    }
+
+    if ( $row[1] eq undef )
+    {
+      push ( @arr, [ $header, [ @pars ] ] );
+    }
+    else
+    {
+      push ( @arr, [ $header, [ @pars ], $row[1], 1 ] );
     }
   } #say $tee "ARR: " . dump( @arr );
   return( \@arr );
 }
 
 
+
 sub pythagoras
 {
   my ( $factbag_ref, $levbag_ref, $stepbag_ref ) = @_;
@@ -1344,7 +1366,6 @@ sub interlinear
 
     if ( $mode__ eq "wei" )
     {
-      #@limbo = @{ dclone( \@limbo_wei ) };
       @limbo = @limbo_wei;
     }
 
@@ -1438,13 +1459,13 @@ foreach my $entry ( @arr )
   my $number = scalar( @{ $entry->[1] } );
   foreach my $item ( @{ $entry->[1] } )
   {
-    if ( not ( $coun == $number ) )
+    if ( ( not ( $coun == $number ) ) and ( not ( $coun == ( $number -1 ) ) ) )
     {
-      print NEWFILE "$item,";
+      print NEWFILE "$item" . "_";
     }
     else
     {
-      print NEWFILE "$item";
+      print NEWFILE "$item" . ",";
     }
     $coun++;
   }
@@ -1485,20 +1506,21 @@ If the configuration file is incomplete or missing, the program adopts its own d
 The only variables that must mandatorily be specified in a configuration file are $sourcefile and (curently)%factlevels.
 The operations entailed are linear but the results of their interplay  are not.
 The operations can be weighted and the strategies can be intermixed.
-The source cvs file has (currently) to be prepared in the format liked by Sim::OPT.
-For example, a multivatiate dataseries with missing entries (in which the numbers of the factors are put into the odd colums and the numbers of the levels are put in the even cdirectoryolums, and in which the last column is kept for the objective function), like the one shown below.
+The source cvs file has to be prepared listing in cvs format in each column the parameter (factor, variable) values (levels) and the last column the objective function value, when present.
+The parameter (variable, factor) number is given by the position of the column (i.e. column 4 host parameter 4).
+Here below is shown an example of multivatiate dataseries of 3 parameters assuming 3 levels with missing objecive function entries.
 
-1,1,2,1,3,1,1.234
-1,1,2,2,3,2,1.500
-1,1,2,3,3,3
-1,2,2,1,3,1,1.534
-1,2,2,2,3,2,0.000
-1,2,2,3,3,0.550
-1,3,2,1,3,1
-1,3,2,2,3,2,0.670directory
-1,3,2,3,3,3
+1,1,1,1.234
+1,2,3,2,1.500
+1,3,3,3
+2,1,3,1,1.534
+2,2,3,2,0.000
+2,3,3,0.550
+3,1,3,1
+3,2,3,2,0.670
+3,3,3,3
 
-...should be edited in the following manner:
+The program converts this format into the one liked by Sim::OPTS, which is the following:
 
 1-1_2-1_3-1,9.234
 1-1_2-2_3-2,4.500
